==> yxy-uni-lowcode-0.0.1.tgz: package/mixins/defaultData.js <==
import { uuid } from "@/utils/util"

const menuList = [
  {
    color: "blue",
    icon: require("@/static/menu/basic.svg"),
    name: "基础组件",
    type: "basic",
  },
  {
    color: "purple",
    icon: require("@/static/menu/form.svg"),
    name: "表单组件",
    type: "form",
  },
  {
    color: "pink",
    icon: require("@/static/menu/data.svg"),
    name: "数据组件",
    type: "data",
  },
  {
    color: "red",
    icon: require("@/static/menu/modal.svg"),
    name: "反馈组件",
    type: "feedback",
  },
  {
    color: "orange",
    icon: require("@/static/menu/layout.svg"),
    name: "布局组件",
    type: "layout",
  },
  {
    color: "green",
    icon: require("@/static/menu/nav.svg"),
    name: "导航组件",
    type: "navigation",
  },
  {
    color: "cyan",
    icon: require("@/static/menu/other.svg"),
    name: "其他组件",
    type: "other",
  },
]

// 引入组件的初始配置数据
const configs = {}
const compConfigs = require.context('../', true, /\.js$/);
compConfigs.keys().forEach(e => {
  const conf = compConfigs(e)
  // console.log(e, conf.default);
  const key = e.substring(e.lastIndexOf('/') + 1, e.lastIndexOf('.'))
  if (conf.default && key.startsWith("r")) {
    configs[key] = conf.default
  }
});
// console.log(configs);

const componentList = []
for (const key in configs) {
  if (key.startsWith("r")) {
    componentList.push({
      key,
      ...configs[key]
    })
  }
}
// console.log(componentList);

/**
 * 对象深度克隆
 * @param {*} target 
 * @returns 
 */
const deepClone = target => {
  // 定义一个变量
  let result;
  // 如果当前需要深拷贝的是一个对象的话
  if (typeof target === 'object') {
    // 如果是一个数组的话
    if (Array.isArray(target)) {
      result = []; // 将result赋值为一个数组，并且执行遍历
      for (let i in target) {
        // 递归克隆数组中的每一项
        result.push(deepClone(target[i]))
      }
      // 判断如果当前的值是null的话；直接赋值为null
    } else if (target === null) {
      result = null;
      // 判断如果当前的值是一个RegExp对象的话，直接赋值    
    } else if (target.constructor === RegExp) {
      result = target;
    } else {
      // 否则是普通对象，直接for in循环，递归赋值对象的所有值
      result = {};
      for (let i in target) {
        result[i] = deepClone(target[i]);
      }
    }
    // 如果不是对象的话，就是基本数据类型，那么直接赋值
  } else {
    result = target;
  }
  // 返回最终结果
  return result;
}

/**
 * 获取组件默认参数
 * @param {*} params 
 * @param {*} context 
 * @returns 
 */
const getData = (key) => {
  const data = deepClone(configs[key])
  let id = uuid()
  data.id = id
  data.key = key
  return data
}

/**
 * 根据类型获取对应的组件列表
 * @param {*} type 
 * @returns 
 */
const getMenusByType = type => {
  const comps = componentList.filter(f => f.menuType == type)
  const reg = new RegExp("^[a-zA-Z]")
  return comps.sort((a, b) => {
    const locale = reg.exec(a.name) || reg.exec(b.name) ? 'en' : 'zh-CN'
    return a.name.localeCompare(b.name, locale)
  })
}

module.exports = {
  menuList,
  deepClone,
  getData,
  getMenusByType,
}

==> yxy-uni-lowcode-0.0.2.tgz: package/mixins/defaultData.js <==
import { uuid } from "@/utils/util"

const menuList = [
  {
    color: "blue",
    icon: require("@/static/menu/basic.svg"),
    name: "基础组件",
    type: "basic",
  },
  {
    color: "purple",
    icon: require("@/static/menu/form.svg"),
    name: "表单组件",
    type: "form",
  },
  {
    color: "pink",
    icon: require("@/static/menu/data.svg"),
    name: "数据组件",
    type: "data",
  },
  {
    color: "red",
    icon: require("@/static/menu/modal.svg"),
    name: "反馈组件",
    type: "feedback",
  },
  {
    color: "orange",
    icon: require("@/static/menu/layout.svg"),
    name: "布局组件",
    type: "layout",
  },
  {
    color: "green",
    icon: require("@/static/menu/nav.svg"),
    name: "导航组件",
    type: "navigation",
  },
  {
    color: "cyan",
    icon: require("@/static/menu/other.svg"),
    name: "其他组件",
    type: "other",
  },
]

// 引入组件的初始配置数据
const configs = {}
const compConfigs = require.context('../', true, /\.js$/);
compConfigs.keys().forEach(e => {
  const conf = compConfigs(e)
  // console.log(e, conf.default);
  const key = e.substring(e.lastIndexOf('/') + 1, e.lastIndexOf('.'))
  if (conf.default && key.startsWith("r")) {
    configs[key] = conf.default
  }
});
// console.log(configs);

// 默认组件数据结构
export const compDefaultData = {
  menuType: "other",
  option: {},
  methods: {},
  dataSources: [],
  compStyle: {},
  slots: [],
  animationClasses: [],
  authentication: false,
  componentVisible: true,
  componentOnClick: () => { }
}

const componentList = []
for (const key in configs) {
  if (key.startsWith("r")) {
    componentList.push({
      ...uni.$u.deepClone(compDefaultData), // 将默认的数据结构填充进去
      key,
      ...configs[key]
    })
  }
}
// console.log(componentList);

/**
 * 对象深度克隆
 * @param {*} target 
 * @returns 
 */
const deepClone = target => {
  // 定义一个变量
  let result;
  // 如果当前需要深拷贝的是一个对象的话
  if (typeof target === 'object') {
    // 如果是一个数组的话
    if (Array.isArray(target)) {
      result = []; // 将result赋值为一个数组，并且执行遍历
      for (let i in target) {
        // 递归克隆数组中的每一项
        result.push(deepClone(target[i]))
      }
      // 判断如果当前的值是null的话；直接赋值为null
    } else if (target === null) {
      result = null;
      // 判断如果当前的值是一个RegExp对象的话，直接赋值    
    } else if (target.constructor === RegExp) {
      result = target;
    } else {
      // 否则是普通对象，直接for in循环，递归赋值对象的所有值
      result = {};
      for (let i in target) {
        result[i] = deepClone(target[i]);
      }
    }
    // 如果不是对象的话，就是基本数据类型，那么直接赋值
  } else {
    result = target;
  }
  // 返回最终结果
  return result;
}

/**
 * 获取组件默认参数
 * @param {*} params 
 * @param {*} context 
 * @returns 
 */
const getData = (key) => {
  const data = deepClone(configs[key])
  let id = uuid()
  data.id = id
  data.key = key
  return data
}

/**
 * 根据类型获取对应的组件列表
 * @param {*} type 
 * @returns 
 */
const getMenusByType = type => {
  const comps = componentList.filter(f => type ? f.menuType == type : (!f.menuType || f.menuType == 'other'))
  const reg = new RegExp("^[a-zA-Z]")
  return comps.sort((a, b) => {
    const locale = reg.exec(a.name) || reg.exec(b.name) ? 'en' : 'zh-CN'
    return a.name.localeCompare(b.name, locale)
  })
}

module.exports = {
  menuList,
  deepClone,
  getData,
  getMenusByType,
}
